@@ -71,7 +71,6 @@ recursive_rmdir (const char *path)
 	g_dir_close (dir);
 }
 
-
 /* unstuff doesn't like file paths starting with /, that's so shite */
 static char *
 unstuff_is_shit_with_filenames (const char *orig)
@@ -102,7 +101,6 @@ unstuff_is_shit_with_filenames (const char *orig)
 	return filename;
 }
 
-
 static void
 process_line (char     *line,
 	      gpointer  data)
@@ -178,7 +176,6 @@ process_line (char     *line,
 	g_free (real_filename);
 }
 
-
 static void
 list__begin (gpointer data)
 {
@@ -187,7 +184,6 @@ list__begin (gpointer data)
 	comm->fdata = NULL;
 }
 
-
 static void
 fr_command_unstuff_list (FrCommand *comm)
 {
@@ -218,7 +214,6 @@ fr_command_unstuff_list (FrCommand *comm)
 	fr_process_start (comm->process);
 }
 
-
 static void
 fr_command_unstuff_extract (FrCommand  *comm,
 			    const char  *from_file,
@@ -263,7 +258,6 @@ fr_command_unstuff_extract (FrCommand  *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 fr_command_unstuff_handle_error (FrCommand   *comm,
 				 FrProcError *error)
@@ -275,23 +269,20 @@ fr_command_unstuff_handle_error (FrCommand   *comm,
 	}
 }
 
-
 const char *unstuff_mime_type[] = { "application/x-stuffit", NULL };
 
-
 static const char **
 fr_command_unstuff_get_mime_types (FrCommand *comm)
 {
 	return unstuff_mime_type;
 }
 
-
-static FrCommandCap
+static FrCommandCaps
 fr_command_unstuff_get_capabilities (FrCommand  *comm,
 			             const char *mime_type,
 				     gboolean    check_command)
 {
-	FrCommandCap capabilities;
+	FrCommandCaps capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 	if (is_program_available ("unstuff", check_command))
@@ -300,7 +291,6 @@ fr_command_unstuff_get_capabilities (FrCommand  *comm,
 	return capabilities;
 }
 
-
 static const char *
 fr_command_unstaff_get_packages (FrCommand  *comm,
 			         const char *mime_type)
@@ -308,7 +298,6 @@ fr_command_unstaff_get_packages (FrCommand  *comm,
 	return PACKAGES ("unstaff");
 }
 
-
 static void
 fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 {
@@ -330,7 +319,6 @@ fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 	afc->get_packages     = fr_command_unstaff_get_packages;
 }
 
-
 static void
 fr_command_unstuff_init (FrCommand *comm)
 {
@@ -343,7 +331,6 @@ fr_command_unstuff_init (FrCommand *comm)
 	comm->propTest                     = FALSE;
 }
 
-
 static void
 fr_command_unstuff_finalize (GObject *object)
 {
@@ -361,7 +348,6 @@ fr_command_unstuff_finalize (GObject *object)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-
 GType
 fr_command_unstuff_get_type ()
 {
